
import java.io.IOException;
import java.io.PrintWriter;
import java.util.Enumeration;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

public class SessionExample extends HttpServlet {

  public void doPost(HttpServletRequest request, HttpServletResponse response)
      throws IOException, ServletException { // Set the content type.
    response.setContentType("text/html");

    // Get a writer for the response.
    PrintWriter out = response.getWriter();

    // Create the html content.
    out.println("<html>");
    out.println("<head>");
    String title = "Session Demonstration";
    out.println("<title>" + title + "</title>");
    out.println("</head>");
    out.println("<body>");
    out.println("<h3>" + title + "</h3>");

    // Get the session (or create a new one).
    HttpSession session = request.getSession();
    ServletUtil.echoSessionInfo(session, out);

    // Echo misc. informaton.
    ServletUtil.echoRequestMethodLineInfo(request, out);
    ServletUtil.echoRequestHeaders(request, out);
    ServletUtil.echoRequestParameters(request, out);

    // Render the form.
    renderForm(response, out);

    // Read form parameters.
    String dataName = request.getParameter("dataname");
    String dataValue = request.getParameter("datavalue");
    String command = request.getParameter("submitCmd");

    System.out.println("dataName: " + dataName);
    System.out.println("dataValue: " + dataValue);
    System.out.println("command: " + command);

    if (command == null) // Sufficient to check for null.
      // Not sufficient to just call session.isNew().
      // List the data in the session.
      listSessionData(session, out); // Should be empty.
    else if (command.equalsIgnoreCase("Add")) { // Subsequent
      // requests
      if (!dataName.equals("") && !dataValue.equals(""))
        // Add parameters to the session.
        session.setAttribute(dataName, dataValue);
      // List the data in the session.
      listSessionData(session, out);
    } else if (command.equalsIgnoreCase("Clear")) // Invalidated.
      session.invalidate();

    out.println("</body>");
    out.println("</html>");
    out.flush();
    out.close();
  }

  private void renderForm(HttpServletResponse response, PrintWriter out)
      throws IOException, ServletException {
    out.println("<p>");
    out.print("<form action=\"");
    out.print(response.encodeURL("/mySession/SessionExample"));
    out.print("\" ");
    out.println("method=POST>");
    out.println("Attribute Name:");
    out.println("<input type=text size=20 name=dataname>");
    out.println("<br>");
    out.println("Attribute Value:");
    out.println("<input type=text size=20 name=datavalue>");
    out.println("<br><br>");
    out.println("<input type=submit name=submitCmd value=Add>");
    out.println("<input type=submit name=submitCmd value=Clear>");
    out.println("</form>");
    out.println("</p>");
  }

  private void listSessionData(HttpSession session, PrintWriter out)
      throws IOException, ServletException {
    out.println("<p>");
    Enumeration names = session.getAttributeNames();
    String attributes = "";
    while (names.hasMoreElements()) {
      String name = (String) names.nextElement();
      String value = session.getAttribute(name).toString();
      attributes += (name + ": " + value + "<br>");
    }
    if (attributes.equals(""))
      out.println("No data in the session." + "<br>");
    else {
      out.println("Data in the Current Session" + "<br>");
      out.println(attributes);
    }
    out.println("</p>");
  }

  public void doGet(HttpServletRequest request, HttpServletResponse response)
      throws IOException, ServletException {
    doPost(request, response);
  }
}